@@ -115,7 +115,7 @@ class CLIParser:
         )
 
         # Module-specific argument sets
-        if not any(module in sys.argv[0] for module in ["analyse"]):
+        if not any(module in sys.argv[0] for module in ["compare"]):
             parser.add_argument(
                 "--variable",
                 "-v",
@@ -137,7 +137,7 @@ class CLIParser:
                 "cloudwizard",
                 "follow",
                 "list",
-                "analyse",
+                "compare",
             ]
         ):
             self.namespace_required = True
@@ -245,9 +245,17 @@ class CLIParser:
                 "-C",
                 type=int,
                 required=False,
-                help="the number of times to submit the Task",
+                help="the number of tasks to submit (copies of a single task)",
                 metavar="<task_count>",
             )
+            parser.add_argument(
+                "--task-group-count",
+                "-G",
+                type=int,
+                required=False,
+                help="the number of task groups to submit (copies of a single task group)",
+                metavar="<task_group_count>",
+            )
             parser.add_argument(
                 "--task-batch-size",
                 "-b",
@@ -301,7 +309,6 @@ class CLIParser:
                 "-l",
                 type=int,
                 required=False,
-                default=MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS,
                 help=(
                     "the maximum number of parallel task batch "
                     f"uploads (default={MAX_PARALLEL_TASK_BATCH_UPLOAD_THREADS})"
@@ -1113,13 +1120,13 @@ class CLIParser:
                 ),
             )
 
-        if "analyse" in sys.argv[0]:
+        if "compare" in sys.argv[0]:
             parser.add_argument(
                 "wr_or_tg_id",
                 metavar="<work-requirement-or-task-group-ID>",
                 type=str,
                 help=(
-                    "the YellowDog ID of the work requirement or task group to be analysed"
+                    "the YellowDog ID of the work requirement or task group to be compared"
                 ),
             )
             parser.add_argument(
@@ -1127,7 +1134,7 @@ class CLIParser:
                 metavar="<worker-pool-ID>",
                 type=str,
                 nargs="+",
-                help="the YellowDog ID(s) of the worker pool(s) to analyse",
+                help="the YellowDog ID(s) of the worker pool(s) to compare",
             )
 
         self.args = parser.parse_args()
@@ -1330,6 +1337,11 @@ class CLIParser:
     def task_count(self) -> Optional[int]:
         return self.args.task_count
 
+    @property
+    @allow_missing_attribute
+    def task_group_count(self) -> Optional[int]:
+        return self.args.task_group_count
+
     @property
     @allow_missing_attribute
     def csv_files(self) -> Optional[List[str]]:
@@ -1668,9 +1680,9 @@ def lookup_module_description(module_name: str) -> Optional[str]:
         suffix = "boosting Allowances"
     elif "show" in module_name:
         suffix = "showing the JSON details of entities referenced by their YDIDs"
-    elif "analyse" in module_name:
+    elif "compare" in module_name:
         suffix = (
-            "analysing if a work requirement or single task group is matched by "
+            "comparing whether a work requirement or task group is matched by "
             "workers in the specified worker pools"
         )
 
